/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call;

/**
 * Class VMSLibrary is a base class for VMS library wrappers,
 */
public class VMSLibrary {
	/**
	 * Class Result contain a return status code plus a return value.
	 *
	 * @param <T> type of return value
	 */
	public static class Result<T> {
		private int status;
		private T result;
		/**
		 * Construct new instance.
		 * @param status return status code
		 * @param result return value
		 */
		public Result(int status, T result) {
			this.status = status;
			this.result = result;
		}
		/**
		 * Get return status code.
		 * @return return status code.
		 */
		public int getStatus() {
			return status;
		}
		/**
		 * Get result value.
		 * @return result value
		 */
		public T getResult() {
			return result;
		}
	}
	/**
	 * Class Pair contain two values.
	 *
	 * @param <T1> type of first value
	 * @param <T2> type of second value
	 */
	public static class Pair<T1,T2> {
		private T1 item1;
		private T2 item2;
		/**
		 * Construct instance.
		 * @param item1 first value
		 * @param item2 second value
		 */
		public Pair(T1 item1, T2 item2) {
			this.item1 = item1;
			this.item2 = item2;
		}
		/**
		 * Get first value.
		 * @return first value
		 */
		public T1 getItem1() {
			return item1;
		}
		/**
		 * Get second value.
		 * @return second value
		 */
		public T2 getItem2() {
			return item2;
		}
	}
}
